bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDToGaussianWishart.plot
===========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDToGaussianWishart.plot